@@ -2,6 +2,7 @@ from enum import Enum
 
 from flexmock import flexmock
 
+import borgmatic.hooks.monitor
 from borgmatic.hooks import ntfy as module
 
 default_base_url = 'https://ntfy.sh'
@@ -37,11 +38,73 @@ def test_ping_monitor_minimal_config_hits_hosted_ntfy_on_fail():
     hook_config = {'topic': topic}
     flexmock(module.requests).should_receive('post').with_args(
         f'{default_base_url}/{topic}',
-        headers=return_default_message_headers(module.monitor.State.FAIL),
+        headers=return_default_message_headers(borgmatic.hooks.monitor.State.FAIL),
+        auth=None,
     ).and_return(flexmock(ok=True)).once()
 
     module.ping_monitor(
-        hook_config, 'config.yaml', module.monitor.State.FAIL, monitoring_log_level=1, dry_run=False
+        hook_config,
+        'config.yaml',
+        borgmatic.hooks.monitor.State.FAIL,
+        monitoring_log_level=1,
+        dry_run=False,
+    )
+
+
+def test_ping_monitor_with_auth_hits_hosted_ntfy_on_fail():
+    hook_config = {
+        'topic': topic,
+        'username': 'testuser',
+        'password': 'fakepassword',
+    }
+    flexmock(module.requests).should_receive('post').with_args(
+        f'{default_base_url}/{topic}',
+        headers=return_default_message_headers(borgmatic.hooks.monitor.State.FAIL),
+        auth=module.requests.auth.HTTPBasicAuth('testuser', 'fakepassword'),
+    ).and_return(flexmock(ok=True)).once()
+
+    module.ping_monitor(
+        hook_config,
+        'config.yaml',
+        borgmatic.hooks.monitor.State.FAIL,
+        monitoring_log_level=1,
+        dry_run=False,
+    )
+
+
+def test_ping_monitor_auth_with_no_username_warning():
+    hook_config = {'topic': topic, 'password': 'fakepassword'}
+    flexmock(module.requests).should_receive('post').with_args(
+        f'{default_base_url}/{topic}',
+        headers=return_default_message_headers(borgmatic.hooks.monitor.State.FAIL),
+        auth=None,
+    ).and_return(flexmock(ok=True)).once()
+    flexmock(module.logger).should_receive('warning').once()
+
+    module.ping_monitor(
+        hook_config,
+        'config.yaml',
+        borgmatic.hooks.monitor.State.FAIL,
+        monitoring_log_level=1,
+        dry_run=False,
+    )
+
+
+def test_ping_monitor_auth_with_no_password_warning():
+    hook_config = {'topic': topic, 'username': 'testuser'}
+    flexmock(module.requests).should_receive('post').with_args(
+        f'{default_base_url}/{topic}',
+        headers=return_default_message_headers(borgmatic.hooks.monitor.State.FAIL),
+        auth=None,
+    ).and_return(flexmock(ok=True)).once()
+    flexmock(module.logger).should_receive('warning').once()
+
+    module.ping_monitor(
+        hook_config,
+        'config.yaml',
+        borgmatic.hooks.monitor.State.FAIL,
+        monitoring_log_level=1,
+        dry_run=False,
     )
 
 
@@ -52,7 +115,7 @@ def test_ping_monitor_minimal_config_does_not_hit_hosted_ntfy_on_start():
     module.ping_monitor(
         hook_config,
         'config.yaml',
-        module.monitor.State.START,
+        borgmatic.hooks.monitor.State.START,
         monitoring_log_level=1,
         dry_run=False,
     )
@@ -65,7 +128,7 @@ def test_ping_monitor_minimal_config_does_not_hit_hosted_ntfy_on_finish():
     module.ping_monitor(
         hook_config,
         'config.yaml',
-        module.monitor.State.FINISH,
+        borgmatic.hooks.monitor.State.FINISH,
         monitoring_log_level=1,
         dry_run=False,
     )
@@ -75,11 +138,16 @@ def test_ping_monitor_minimal_config_hits_selfhosted_ntfy_on_fail():
     hook_config = {'topic': topic, 'server': custom_base_url}
     flexmock(module.requests).should_receive('post').with_args(
         f'{custom_base_url}/{topic}',
-        headers=return_default_message_headers(module.monitor.State.FAIL),
+        headers=return_default_message_headers(borgmatic.hooks.monitor.State.FAIL),
+        auth=None,
     ).and_return(flexmock(ok=True)).once()
 
     module.ping_monitor(
-        hook_config, 'config.yaml', module.monitor.State.FAIL, monitoring_log_level=1, dry_run=False
+        hook_config,
+        'config.yaml',
+        borgmatic.hooks.monitor.State.FAIL,
+        monitoring_log_level=1,
+        dry_run=False,
     )
 
 
@@ -88,18 +156,26 @@ def test_ping_monitor_minimal_config_does_not_hit_hosted_ntfy_on_fail_dry_run():
     flexmock(module.requests).should_receive('post').never()
 
     module.ping_monitor(
-        hook_config, 'config.yaml', module.monitor.State.FAIL, monitoring_log_level=1, dry_run=True
+        hook_config,
+        'config.yaml',
+        borgmatic.hooks.monitor.State.FAIL,
+        monitoring_log_level=1,
+        dry_run=True,
     )
 
 
 def test_ping_monitor_custom_message_hits_hosted_ntfy_on_fail():
     hook_config = {'topic': topic, 'fail': custom_message_config}
     flexmock(module.requests).should_receive('post').with_args(
-        f'{default_base_url}/{topic}', headers=custom_message_headers,
+        f'{default_base_url}/{topic}', headers=custom_message_headers, auth=None
     ).and_return(flexmock(ok=True)).once()
 
     module.ping_monitor(
-        hook_config, 'config.yaml', module.monitor.State.FAIL, monitoring_log_level=1, dry_run=False
+        hook_config,
+        'config.yaml',
+        borgmatic.hooks.monitor.State.FAIL,
+        monitoring_log_level=1,
+        dry_run=False,
     )
 
 
@@ -107,13 +183,14 @@ def test_ping_monitor_custom_state_hits_hosted_ntfy_on_start():
     hook_config = {'topic': topic, 'states': ['start', 'fail']}
     flexmock(module.requests).should_receive('post').with_args(
         f'{default_base_url}/{topic}',
-        headers=return_default_message_headers(module.monitor.State.START),
+        headers=return_default_message_headers(borgmatic.hooks.monitor.State.START),
+        auth=None,
     ).and_return(flexmock(ok=True)).once()
 
     module.ping_monitor(
         hook_config,
         'config.yaml',
-        module.monitor.State.START,
+        borgmatic.hooks.monitor.State.START,
         monitoring_log_level=1,
         dry_run=False,
     )
@@ -123,14 +200,15 @@ def test_ping_monitor_with_connection_error_logs_warning():
     hook_config = {'topic': topic}
     flexmock(module.requests).should_receive('post').with_args(
         f'{default_base_url}/{topic}',
-        headers=return_default_message_headers(module.monitor.State.FAIL),
+        headers=return_default_message_headers(borgmatic.hooks.monitor.State.FAIL),
+        auth=None,
     ).and_raise(module.requests.exceptions.ConnectionError)
     flexmock(module.logger).should_receive('warning').once()
 
     module.ping_monitor(
         hook_config,
         'config.yaml',
-        module.monitor.State.FAIL,
+        borgmatic.hooks.monitor.State.FAIL,
         monitoring_log_level=1,
         dry_run=False,
     )
@@ -144,14 +222,15 @@ def test_ping_monitor_with_other_error_logs_warning():
     )
     flexmock(module.requests).should_receive('post').with_args(
         f'{default_base_url}/{topic}',
-        headers=return_default_message_headers(module.monitor.State.FAIL),
+        headers=return_default_message_headers(borgmatic.hooks.monitor.State.FAIL),
+        auth=None,
     ).and_return(response)
     flexmock(module.logger).should_receive('warning').once()
 
     module.ping_monitor(
         hook_config,
         'config.yaml',
-        module.monitor.State.FAIL,
+        borgmatic.hooks.monitor.State.FAIL,
         monitoring_log_level=1,
         dry_run=False,
     )
